@@ -813,7 +813,14 @@ gnome_print_ps2_close (GnomePrintContext *pc)
 
 	g_return_val_if_fail (pc->transport != NULL, GNOME_PRINT_ERROR_UNKNOWN);
 
-	if (!ps2->pages || !ps2->pages->shown) {
+	if (!ps2->pages) {
+		gnome_print_transport_close (pc->transport);
+		g_object_unref (G_OBJECT (pc->transport));
+		pc->transport = NULL; 
+		return GNOME_PRINT_OK;
+	}
+
+	if (!ps2->pages->shown) {
 		g_warning ("file %s: line %d: Closing PS2 context without final showpage", __FILE__, __LINE__);
 		ret = gnome_print_showpage (pc);
 		g_return_val_if_fail (ret != GNOME_PRINT_OK, ret);
